"""Convert date/time into a string relative to now.

Possible input types:
* time.time()
* datetime.date.today()
* datetime.datetime.now()

Output:
    <int> <unit> <text>

Examples:
```python
import datetime
from RelativeToNow import relative_to_now

print(relative_to_now(datetime.datetime.now() + datetime.timedelta(days=1)))
>>> 1 day from now
```

Precision for `datetime.date` is days.
```python
import datetime
from RelativeToNow import relative_to_now

print(relative_to_now(datetime.date.today() - datetime.timedelta(days=1)))
>>> 1 day ago
```

```python
import time
from RelativeToNow import relative_to_now

print(relative_to_now(time.time()))
>>> 0 seconds from now
```
"""


import datetime
import time


def relative_to_now(start_date, no_error=False):
    """Verify date and return converted."""
    if isinstance(start_date, datetime.datetime):
        if start_date.tzinfo:
            diff = datetime.datetime.now(start_date.tzinfo) - start_date
        else:
            diff = datetime.datetime.now() - start_date
        abs_seconds = diff.days * 3600 * 24 + diff.seconds

    elif isinstance(start_date, datetime.date):
        diff = datetime.date.today() - start_date
        abs_seconds = diff.days * 3600 * 24 + diff.seconds

    elif isinstance(start_date, float):  # noqa: SIM106
        abs_seconds = int(time.time() - start_date)

    else:
        if no_error:
            return start_date

        raise Exception("type must be date or datetime.")

    return convert(abs_seconds, start_date)


def build_string(unit, value, my_text):
    """Build string from params."""
    unit = unit if value == 1 else unit + "s"
    return f"{value} {unit} {my_text}"


def convert(abs_seconds, output):
    """Convert date to string."""
    my_text = "ago" if abs_seconds > 0 else "from now"
    abs_seconds = abs(abs_seconds)

    seconds = abs_seconds // 1
    minutes = abs_seconds // 60
    hours = abs_seconds // 3600
    days = abs_seconds // (3600 * 24)
    weeks = abs_seconds // (3600 * 24 * 7)
    months = int(abs_seconds // (3600 * 24 * 7 * (365 / 12 / 7)))
    years = abs_seconds // (3600 * 24 * 365)

    if seconds == 0:
        output = "just now"

    elif seconds < 60:
        output = build_string("second", seconds, my_text)

    elif minutes < 60:
        output = build_string("minute", minutes, my_text)

    elif hours < 24:
        output = build_string("hour", hours, my_text)

    elif days < 7:
        output = build_string("day", days, my_text)

    elif weeks < 5:
        output = build_string("week", weeks, my_text)

    elif months < 12:
        output = build_string("month", months, my_text)

    elif years >= 1:
        output = build_string("year", years, my_text)

    return output



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['RelativeToNow']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'relative-to-now',
    'version': '1.1.0',
    'description': "Print a datetime's distance from now",
    'long_description': '\n<h1 align="center">Relative To Now</h1>\n\n<h4 align="center">Convert date/time into a string relative to now.</h4>\n\n<p align="center">\n  <a href="https://pypi.org/project/relative-to-now/">\n    <img src="https://img.shields.io/badge/Python-3.7%20%7C%203.8%20%7C%203.9-blue" alt="Python Version">\n  </a>\n  <a href="https://codecov.io/gh/Riverside-Healthcare/RelativeToNow">\n    <img src="https://codecov.io/gh/Riverside-Healthcare/RelativeToNow/branch/master/graph/badge.svg?token=PHYGI9FI22" alt="Codecov Status">\n  </a>\n  <a href="https://www.codacy.com/gh/Riverside-Healthcare/RelativeToNow/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Riverside-Healthcare/RelativeToNow&amp;utm_campaign=Badge_Grade">\n    <img src="https://app.codacy.com/project/badge/Grade/2533c8838ffe4c6a82c889d6d98f2050" alt="Codacy Status">\n  </a>\n  <a href="https://pypi.org/project/relative-to-now/">\n    <img src="https://badgen.net/pypi/v/relative-to-now" alt="Pypi Download">\n  </a>\n  <a href="https://pepy.tech/project/relative-to-now">\n    <img src="https://static.pepy.tech/badge/relative-to-now" alt="Downloads">\n  </a>\n</p>\n\n\n## 💾 Install\n\n```sh\npython -m pip install relative-to-now\n\n# or\n\npoetry add relative-to-now\n```\n\n## ✨ How to Use\n\nPossible input types:\n\n  * time.time()\n  * datetime.date.today()\n  * datetime.datetime.now()\n\nOptional inputs:\n\n  * ``no_errors`` (Defaults to ``False``, set to ``True`` to return value when there is an error instead of raising)\n\nOutput:\n    <int> <unit> <text>\n\nExamples:\n```python\nimport datetime\nfrom RelativeToNow import relative_to_now\n\nprint(relative_to_now(datetime.datetime.now() + datetime.timedelta(days=1)))\n>>> 1 day from now\n```\n\nPrecision for `datetime.date` is days.\n```python\nimport datetime\nfrom RelativeToNow import relative_to_now\n\nprint(relative_to_now(datetime.date.today() - datetime.timedelta(days=2)))\n>>> 2 days ago\n```\n\n```python\nimport time\nfrom RelativeToNow import relative_to_now\n\nprint(relative_to_now(time.time()))\n>>> just now\n```\n',
    'author': 'Christopher Pickering',
    'author_email': 'cpickering@rhc.net',
    'maintainer': 'Christopher Pickering',
    'maintainer_email': 'cpickering@rhc.net',
    'url': 'https://github.com/Riverside-Healthcare/RelativeToNow',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7.2,<4.0.0',
}


setup(**setup_kwargs)
